@@ -1,18 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module defining common data to be used by all modules.
 """
 
+#
+# Note: Do not import any eric stuff in here!!!!!!!
+#
+
 from __future__ import unicode_literals
 
 import sys
 import os
 
-from PyQt5.QtCore import QDir, QLibraryInfo, QByteArray
+from PyQt5.QtCore import (QDir, QLibraryInfo, QByteArray,
+                          QCoreApplication, QT_VERSION_STR)
 
 # names of the various settings objects
 settingsNameOrganization = "Eric6"
@@ -23,6 +28,7 @@ settingsNameRecent = "eric6recent"
 recentNameMultiProject = "MultiProjects"
 recentNameProject = "Projects"
 recentNameFiles = "Files"
+recentNameHexFiles = "HexFiles"
 recentNameHosts = "Hosts6"
 
 configDir = None
@@ -182,9 +188,15 @@ def getQtBinariesPath():
     
     @return path of the Qt binaries (string)
     """
+    import Preferences
+    
     path = ""
-    if isWindowsPlatform():
-        # check for PyQt5 installer first (designer is test object)
+    
+    # step 1: check, if the user has configured a tools path
+    path = Preferences.getQt("QtToolsDir")
+    
+    if not path and isWindowsPlatform():
+        # step 2.1: check for PyQt5 Windows installer (designer is test object)
         modDir = getPyQt5ModulesDirectory()
         if os.path.exists(os.path.join(modDir, "bin", "designer.exe")):
             path = os.path.join(modDir, "bin")
@@ -192,6 +204,8 @@ def getQtBinariesPath():
             path = modDir
     
     if not path:
+        # step 2.2: get the path from Qt
+        # Note: no Qt tools are to found there for PyQt 5.7.0
         path = QLibraryInfo.location(QLibraryInfo.BinariesPath)
         if not os.path.exists(path):
             path = ""
@@ -199,6 +213,20 @@ def getQtBinariesPath():
     return QDir.toNativeSeparators(path)
 
 
+def translate(*args):
+    """
+    Module function to handle different PyQt 4/5 QCoreApplication.translate
+    parameter.
+    
+    @param args tuple of arguments from QCoreApplication.translate (tuple)
+    @return translated string (string)
+    """
+    if QT_VERSION_STR.startswith('4'):
+        args = list(args)
+        args.insert(3, QCoreApplication.CodecForTr)
+    return QCoreApplication.translate(*args)
+
+
 ###############################################################################
 ## functions for searching a Python2/3 interpreter
 ###############################################################################
@@ -243,6 +271,35 @@ def findPythonInterpreters(pyVersion):
     return interpreters
 
 
+###############################################################################
+## functions for extended string handling
+###############################################################################
+
+
+def strGroup(txt, sep, groupLen=4):
+    """
+    Module function to group a string into sub-strings separated by a
+    separator.
+    
+    @param txt text to be grouped
+    @type str
+    @param sep separator string
+    @type str
+    @param groupLen length of each group
+    @type int
+    @return result string
+    @rtype str
+    """
+    groups = []
+    
+    while len(txt) // groupLen != 0:
+        groups.insert(0, txt[-groupLen:])
+        txt = txt[:-groupLen]
+    if len(txt) > 0:
+        groups.insert(0, txt)
+    return sep.join(groups)
+
+
 ###############################################################################
 ## functions for converting QSetting return types to valid types
 ###############################################################################
@@ -302,3 +359,6 @@ def toDict(value):
         return {}
     else:
         return value
+
+#
+# eflag: noqa = M801
