@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,201 +11,249 @@ from __future__ import unicode_literals
 
 from PyQt5.QtCore import QCoreApplication
 
+from Globals import translate
+
 __all__ = ["getTranslatedMessage"]
 
 _messages = {
     "E101": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "indentation contains mixed spaces and tabs"),
     "E111": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "indentation is not a multiple of four"),
     "E112": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "expected an indented block"),
     "E113": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "unexpected indentation"),
+    "E114": QCoreApplication.translate(
+        "pycodestyle",
+        "indentation is not a multiple of four (comment)"),
+    "E115": QCoreApplication.translate(
+        "pycodestyle",
+        "expected an indented block (comment)"),
+    "E116": QCoreApplication.translate(
+        "pycodestyle",
+        "unexpected indentation (comment)"),
     "E121": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line indentation is not a multiple of four"),
     "E122": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line missing indentation or outdented"),
     "E123": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "closing bracket does not match indentation of opening"
         " bracket's line"),
     "E124": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "closing bracket does not match visual indentation"),
     "E125": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line with same indent as next logical line"),
     "E126": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line over-indented for hanging indent"),
     "E127": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line over-indented for visual indent"),
     "E128": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line under-indented for visual indent"),
     "E129": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "visually indented line with same indent as next logical line"),
     "E131": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line unaligned for hanging indent"),
     "E133": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "closing bracket is missing indentation"),
     "W191": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "indentation contains tabs"),
     "E201": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace after '{0}'"),
     "E202": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace before '{0}'"),
     "E203": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace before '{0}'"),
     "E211": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace before '{0}'"),
     "E221": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces before operator"),
     "E222": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces after operator"),
     "E223": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab before operator"),
     "E224": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab after operator"),
     "E225": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around operator"),
     "E226": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around arithmetic operator"),
     "E227": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around bitwise or shift operator"),
     "E228": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around modulo operator"),
     "E231": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace after '{0}'"),
     "E241": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces after '{0}'"),
     "E242": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab after '{0}'"),
     "E251": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "unexpected spaces around keyword / parameter equals"),
     "E261": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "at least two spaces before inline comment"),
     "E262": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "inline comment should start with '# '"),
     "E265": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "block comment should start with '# '"),
+    "E266": QCoreApplication.translate(
+        "pycodestyle",
+        "too many leading '#' for block comment"),
     "E271": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces after keyword"),
     "E272": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces before keyword"),
     "E273": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab after keyword"),
     "E274": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab before keyword"),
+    "E275": QCoreApplication.translate(
+        "pycodestyle",
+        "missing whitespace after keyword"),
     "W291": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "trailing whitespace"),
     "W292": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "no newline at end of file"),
     "W293": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "blank line contains whitespace"),
     "E301": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "expected 1 blank line, found 0"),
     "E302": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "expected 2 blank lines, found {0}"),
     "E303": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "too many blank lines ({0})"),
     "E304": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "blank lines found after function decorator"),
+    "E305": QCoreApplication.translate(
+        "pycodestyle",
+        "expected 2 blank lines after class or function definition,"
+        " found {0}"),
+    "E306": QCoreApplication.translate(
+        "pycodestyle",
+        "expected 1 blank line before a nested definition, found 0"),
     "W391": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "blank line at end of file"),
     "E401": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple imports on one line"),
+    "E402": QCoreApplication.translate(
+        "pycodestyle",
+        "module level import not at top of file"),
     "E501": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "line too long ({0} > {1} characters)"),
     "E502": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "the backslash is redundant between brackets"),
+    "W503": QCoreApplication.translate(
+        "pycodestyle",
+        "line break before binary operator"),
     "W601": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         ".has_key() is deprecated, use 'in'"),
     "W602": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "deprecated form of raising exception"),
     "W603": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "'<>' is deprecated, use '!='"),
     "W604": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "backticks are deprecated, use 'repr()'"),
     "E701": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple statements on one line (colon)"),
     "E702": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple statements on one line (semicolon)"),
     "E703": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "statement ends with a semicolon"),
+    "E704": QCoreApplication.translate(
+        "pycodestyle",
+        "multiple statements on one line (def)"),
+    "E705": QCoreApplication.translate(
+        "pycodestyle",
+        "multiple statements on one line (async def)"),
     "E711": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "comparison to {0} should be {1}"),
     "E712": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "comparison to {0} should be {1}"),
     "E713": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "test for membership should be 'not in'"),
     "E714": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "test for object identity should be 'is not'"),
     "E721": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "do not compare types, use 'isinstance()'"),
+    "E731": QCoreApplication.translate(
+        "pycodestyle",
+        "do not assign a lambda expression, use a def"),
+    "E741": QCoreApplication.translate(
+        "pycodestyle",
+        "ambiguous variable name '{0}'"),
+    "E742": QCoreApplication.translate(
+        "pycodestyle",
+        "ambiguous class definition '{0}'"),
+    "E743": QCoreApplication.translate(
+        "pycodestyle",
+        "ambiguous function definition '{0}'"),
     "E901": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "{0}: {1}"),
     "E902": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "{0}"),
 
     # DocStyleChecker messages
@@ -392,7 +440,7 @@ _messages = {
         "copyright notice contains invalid author"),
     "M121": QCoreApplication.translate(
         "MiscellaneousChecker",
-        "blind except: statement"),
+        "blind except: statement"),         # __IGNORE_WARNING__
     "M601": QCoreApplication.translate(
         "MiscellaneousChecker",
         "found {0} formatter"),
@@ -540,10 +588,10 @@ _messages = {
         'CodeStyleFixer',
         "One blank line inserted."),
     
-    "FE302+": lambda n=1: QCoreApplication.translate(
+    "FE302+": lambda n=1: translate(
         'CodeStyleFixer',
         "%n blank line(s) inserted.", '', n),
-    "FE302-": lambda n=1: QCoreApplication.translate(
+    "FE302-": lambda n=1: translate(
         'CodeStyleFixer',
         "%n superfluous lines removed", '', n),
     
@@ -605,9 +653,13 @@ _messages_sample_args = {
     "E242": [",;:"],
     "E302": [1],
     "E303": [3],
+    "E305": [1],
     "E501": [85, 79],
     "E711": ["None", "'if cond is None:'"],
     "E712": ["True", "'if cond is True:' or 'if cond:'"],
+    "E741": ["l"],
+    "E742": ["l"],
+    "E743": ["l"],
     "E901": ["SyntaxError", "Invalid Syntax"],
     "E902": ["IOError"],
     "D232": ["public"],
