@@ -19,13 +19,14 @@ from Project.ProjectBrowserModel import ProjectBrowserFileItem
 from Utilities import determinePythonVersion
 
 import Preferences
+import UI.Info
 
 # Start-Of-Header
 name = "Code Style Checker Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "6.2.0"
+version = UI.Info.VersionOnly
 className = "CodeStyleCheckerPlugin"
 packageName = "__core__"
 shortDescription = "Show the Python Code Style Checker dialog."
