@@ -19,6 +19,7 @@ from E5Gui.E5Application import e5App
 from E5Gui.E5Action import E5Action
 
 import Utilities
+import UI.Info
 
 from eric6config import getConfig
 
@@ -27,7 +28,7 @@ name = "Ericapi Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "6.2.0"
+version = UI.Info.VersionOnly
 className = "EricapiPlugin"
 packageName = "__core__"
 shortDescription = "Show the Ericapi dialogs."
