@@ -20,7 +20,7 @@ from PyQt5.QtCore import pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, \
     QSize, QPoint
 from PyQt5.QtGui import QCursor, QColor, QPixmap, QPainter, QPen, QBrush, QIcon
 from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QApplication, QLineEdit, QMenu
+    QTreeWidgetItem, QApplication, QLineEdit, QMenu, QInputDialog
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -47,6 +47,7 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
     DateColumn = 5
     MessageColumn = 6
     TagsColumn = 7
+    BookmarksColumn = 8
     
     LargefilesCacheL = ".hglf/"
     LargefilesCacheW = ".hglf\\"
@@ -171,8 +172,6 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
         self.BookmarksColumn = self.logTree.columnCount()
         self.logTree.headerItem().setText(
             self.BookmarksColumn, self.tr("Bookmarks"))
-        if self.vcs.version < (2, 1):
-            self.logTree.setColumnHidden(self.PhaseColumn, True)
         
         self.__initActionsMenu()
     
@@ -181,61 +180,83 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
         Private method to initialize the actions menu.
         """
         self.__actionsMenu = QMenu()
-        if self.vcs.version >= (2, 0):
-            self.__graftAct = self.__actionsMenu.addAction(
-                self.tr("Copy Changesets"), self.__graftActTriggered)
-            self.__graftAct.setToolTip(self.tr(
-                "Copy the selected changesets to the current branch"))
-        else:
-            self.__graftAct = None
+        self.__graftAct = self.__actionsMenu.addAction(
+            UI.PixmapCache.getIcon("vcsGraft.png"),
+            self.tr("Copy Changesets"), self.__graftActTriggered)
+        self.__graftAct.setToolTip(self.tr(
+            "Copy the selected changesets to the current branch"))
         
-        if self.vcs.version >= (2, 1):
-            self.__phaseAct = self.__actionsMenu.addAction(
-                self.tr("Change Phase"), self.__phaseActTriggered)
-            self.__phaseAct.setToolTip(self.tr(
-                "Change the phase of the selected revisions"))
-            self.__phaseAct.setWhatsThis(self.tr(
-                """<b>Change Phase</b>\n<p>This changes the phase of the"""
-                """ selected revisions. The selected revisions have to have"""
-                """ the same current phase.</p>"""))
-        else:
-            self.__phaseAct = None
+        self.__phaseAct = self.__actionsMenu.addAction(
+            self.tr("Change Phase"), self.__phaseActTriggered)
+        self.__phaseAct.setToolTip(self.tr(
+            "Change the phase of the selected revisions"))
+        self.__phaseAct.setWhatsThis(self.tr(
+            """<b>Change Phase</b>\n<p>This changes the phase of the"""
+            """ selected revisions. The selected revisions have to have"""
+            """ the same current phase.</p>"""))
         
         self.__tagAct = self.__actionsMenu.addAction(
-            self.tr("Tag"), self.__tagActTriggered)
+            UI.PixmapCache.getIcon("vcsTag.png"), self.tr("Tag"),
+            self.__tagActTriggered)
         self.__tagAct.setToolTip(self.tr("Tag the selected revision"))
         
         self.__switchAct = self.__actionsMenu.addAction(
-            self.tr("Switch"), self.__switchActTriggered)
+            UI.PixmapCache.getIcon("vcsSwitch.png"), self.tr("Switch"),
+            self.__switchActTriggered)
         self.__switchAct.setToolTip(self.tr(
             "Switch the working directory to the selected revision"))
         
         self.__actionsMenu.addSeparator()
         
+        self.__bookmarkAct = self.__actionsMenu.addAction(
+            UI.PixmapCache.getIcon("addBookmark.png"),
+            self.tr("Define Bookmark..."), self.__bookmarkActTriggered)
+        self.__bookmarkAct.setToolTip(
+            self.tr("Bookmark the selected revision"))
+        self.__bookmarkMoveAct = self.__actionsMenu.addAction(
+            UI.PixmapCache.getIcon("moveBookmark.png"),
+            self.tr("Move Bookmark..."), self.__bookmarkMoveActTriggered)
+        self.__bookmarkMoveAct.setToolTip(
+            self.tr("Move bookmark to the selected revision"))
+        
+        self.__actionsMenu.addSeparator()
+        
         self.__pullAct = self.__actionsMenu.addAction(
-            self.tr("Pull Changes"), self.__pullActTriggered)
+            UI.PixmapCache.getIcon("vcsUpdate.png"), self.tr("Pull Changes"),
+            self.__pullActTriggered)
         self.__pullAct.setToolTip(self.tr(
             "Pull changes from a remote repository"))
-        if self.vcs.version >= (2, 0):
-            self.__lfPullAct = self.__actionsMenu.addAction(
-                self.tr("Pull Large Files"), self.__lfPullActTriggered)
-            self.__lfPullAct.setToolTip(self.tr(
-                "Pull large files for selected revisions"))
-        else:
-            self.__lfPullAct = None
+        self.__lfPullAct = self.__actionsMenu.addAction(
+            self.tr("Pull Large Files"), self.__lfPullActTriggered)
+        self.__lfPullAct.setToolTip(self.tr(
+            "Pull large files for selected revisions"))
+        self.__fetchAct = self.__actionsMenu.addAction(
+            self.tr("Fetch Changes"), self.__fetchActTriggered)
+        self.__fetchAct.setToolTip(self.tr(
+            "Fetch changes from a remote repository"))
         
         self.__actionsMenu.addSeparator()
         
         self.__pushAct = self.__actionsMenu.addAction(
+            UI.PixmapCache.getIcon("vcsCommit.png"),
             self.tr("Push Selected Changes"), self.__pushActTriggered)
         self.__pushAct.setToolTip(self.tr(
             "Push changes of the selected changeset and its ancestors"
             " to a remote repository"))
         self.__pushAllAct = self.__actionsMenu.addAction(
+            UI.PixmapCache.getIcon("vcsCommit.png"),
             self.tr("Push All Changes"), self.__pushAllActTriggered)
         self.__pushAllAct.setToolTip(self.tr(
             "Push all changes to a remote repository"))
         
+        self.__actionsMenu.addSeparator()
+        
+        self.__stripAct = self.__actionsMenu.addAction(
+            UI.PixmapCache.getIcon("fileDelete.png"),
+            self.tr("Strip Changesets"), self.__stripActTriggered)
+        self.__stripAct.setToolTip(self.tr(
+            "Strip changesets from a repository"))
+        
         self.actionsButton.setIcon(
             UI.PixmapCache.getIcon("actionsToolButton.png"))
         self.actionsButton.setMenu(self.__actionsMenu)
@@ -791,21 +812,10 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
             args.append('--follow')
         if self.commandMode == "log":
             args.append('--copies')
-        if self.vcs.version >= (3, 0):
-            args.append('--template')
-            args.append(os.path.join(os.path.dirname(__file__),
-                                     "templates",
-                                     "logBrowserBookmarkPhase.tmpl"))
-        else:
-            args.append('--style')
-            if self.vcs.version >= (2, 1):
-                args.append(os.path.join(os.path.dirname(__file__),
-                                         "styles",
-                                         "logBrowserBookmarkPhase.style"))
-            else:
-                args.append(os.path.join(os.path.dirname(__file__),
-                                         "styles",
-                                         "logBrowserBookmark.style"))
+        args.append('--template')
+        args.append(os.path.join(os.path.dirname(__file__),
+                                 "templates",
+                                 "logBrowserBookmarkPhase.tmpl"))
         if self.commandMode == "incoming":
             if self.__bundle:
                 args.append(self.__bundle)
@@ -1254,18 +1264,36 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
             
             self.__tagAct.setEnabled(len(self.logTree.selectedItems()) == 1)
             self.__switchAct.setEnabled(len(self.logTree.selectedItems()) == 1)
+            self.__bookmarkAct.setEnabled(
+                len(self.logTree.selectedItems()) == 1)
+            self.__bookmarkMoveAct.setEnabled(
+                len(self.logTree.selectedItems()) == 1)
             
-            if self.__lfPullAct is not None:
-                if self.vcs.isExtensionActive("largefiles"):
-                    self.__lfPullAct.setEnabled(bool(
-                        self.logTree.selectedItems()))
-                else:
-                    self.__lfPullAct.setEnabled(False)
+            if self.vcs.canPull():
+                self.__pullAct.setEnabled(True)
+                self.__lfPullAct.setEnabled(
+                    self.vcs.isExtensionActive("largefiles") and
+                    bool(self.logTree.selectedItems()))
+                self.__fetchAct.setEnabled(
+                    self.vcs.isExtensionActive("fetch"))
+            else:
+                self.__pullAct.setEnabled(False)
+                self.__lfPullAct.setEnabled(False)
+                self.__fetchAct.setEnabled(False)
             
-            self.__pushAct.setEnabled(
-                len(self.logTree.selectedItems()) == 1 and
-                self.logTree.selectedItems()[0].text(self.PhaseColumn) ==
-                self.phases["draft"])
+            if self.vcs.canPush():
+                self.__pushAct.setEnabled(
+                    len(self.logTree.selectedItems()) == 1 and
+                    self.logTree.selectedItems()[0].text(self.PhaseColumn) ==
+                    self.phases["draft"])
+                self.__pushAllAct.setEnabled(True)
+            else:
+                self.__pushAct.setEnabled(False)
+                self.__pushAllAct.setEnabled(False)
+            
+            self.__stripAct.setEnabled(
+                self.vcs.isExtensionActive("strip") and
+                len(self.logTree.selectedItems()) == 1)
             
             self.actionsButton.setEnabled(True)
         else:
@@ -1707,6 +1735,21 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
         if len(self.logTree.selectedItems()) == 1:
             itm = self.logTree.selectedItems()[0]
             rev = itm.text(self.RevisionColumn).strip().split(":", 1)[0]
+            bookmarks = [bm.strip() for bm in
+                         itm.text(self.BookmarksColumn).strip().split(",")
+                         if bm.strip()]
+            if bookmarks:
+                bookmark, ok = QInputDialog.getItem(
+                    self,
+                    self.tr("Switch"),
+                    self.tr("Select bookmark to switch to (leave empty to"
+                            " use revision):"),
+                    [""] + bookmarks,
+                    0, False)
+                if not ok:
+                    return
+                if bookmark:
+                    rev = bookmark
             if rev:
                 shouldReopen = self.vcs.vcsUpdate(self.repodir, revision=rev)
                 if shouldReopen:
@@ -1722,6 +1765,50 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
                 
                 self.on_refreshButton_clicked()
     
+    @pyqtSlot()
+    def __bookmarkActTriggered(self):
+        """
+        Private slot to bookmark the selected revision.
+        """
+        if len(self.logTree.selectedItems()) == 1:
+            itm = self.logTree.selectedItems()[0]
+            rev, changeset = \
+                itm.text(self.RevisionColumn).strip().split(":", 1)
+            bookmark, ok = QInputDialog.getText(
+                self,
+                self.tr("Define Bookmark"),
+                self.tr('Enter bookmark name for changeset "{0}":').format(
+                    changeset),
+                QLineEdit.Normal)
+            if ok and bool(bookmark):
+                self.vcs.hgBookmarkDefine(
+                    self.repodir, revision="rev({0})".format(rev),
+                    bookmark=bookmark)
+                self.on_refreshButton_clicked()
+    
+    @pyqtSlot()
+    def __bookmarkMoveActTriggered(self):
+        """
+        Private slot to move a bookmark to the selected revision.
+        """
+        if len(self.logTree.selectedItems()) == 1:
+            itm = self.logTree.selectedItems()[0]
+            rev, changeset = \
+                itm.text(self.RevisionColumn).strip().split(":", 1)
+            bookmarksList = self.vcs.hgGetBookmarksList(self.repodir)
+            bookmark, ok = QInputDialog.getItem(
+                self,
+                self.tr("Move Bookmark"),
+                self.tr('Select the bookmark to be moved  to changeset'
+                        ' "{0}":').format(changeset),
+                [""] + bookmarksList,
+                0, False)
+            if ok and bool(bookmark):
+                self.vcs.hgBookmarkMove(
+                    self.repodir, revision="rev({0})".format(rev),
+                    bookmark=bookmark)
+                self.on_refreshButton_clicked()
+    
     @pyqtSlot()
     def __lfPullActTriggered(self):
         """
@@ -1737,12 +1824,43 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
             self.vcs.getExtensionObject("largefiles").hgLfPull(
                 self.repodir, revisions=revs)
     
+    @pyqtSlot()
+    def __fetchActTriggered(self):
+        """
+        Private slot to fetch changes from a remote repository.
+        """
+        shouldReopen = self.vcs.getExtensionObject("fetch").hgFetch(
+            self.repodir)
+        if shouldReopen:
+            res = E5MessageBox.yesNo(
+                None,
+                self.tr("Fetch Changes"),
+                self.tr(
+                    """The project should be reread. Do this now?"""),
+                yesDefault=True)
+            if res:
+                e5App().getObject("Project").reopenProject()
+                return
+        
+        self.on_refreshButton_clicked()
+    
     @pyqtSlot()
     def __pullActTriggered(self):
         """
         Private slot to pull changes from a remote repository.
         """
-        self.vcs.hgPull(self.repodir)
+        shouldReopen = self.vcs.hgPull(self.repodir)
+        if shouldReopen:
+            res = E5MessageBox.yesNo(
+                None,
+                self.tr("Pull Changes"),
+                self.tr(
+                    """The project should be reread. Do this now?"""),
+                yesDefault=True)
+            if res:
+                e5App().getObject("Project").reopenProject()
+                return
+        
         self.on_refreshButton_clicked()
     
     @pyqtSlot()
@@ -1765,6 +1883,28 @@ class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
         self.vcs.hgPush(self.repodir)
         self.on_refreshButton_clicked()
     
+    @pyqtSlot()
+    def __stripActTriggered(self):
+        """
+        Private slot to strip changesets from the repository.
+        """
+        itm = self.logTree.selectedItems()[0]
+        rev = itm.text(self.RevisionColumn).strip().split(":", 1)[1]
+        shouldReopen = self.vcs.getExtensionObject("strip").hgStrip(
+            self.repodir, rev=rev)
+        if shouldReopen:
+            res = E5MessageBox.yesNo(
+                None,
+                self.tr("Strip Changesets"),
+                self.tr(
+                    """The project should be reread. Do this now?"""),
+                yesDefault=True)
+            if res:
+                e5App().getObject("Project").reopenProject()
+                return
+        
+        self.on_refreshButton_clicked()
+    
     def __actionMode(self):
         """
         Private method to get the selected action mode.
