@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -394,7 +394,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -478,7 +478,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                         self.hooks["open"](itm.fileName())
                     else:
                         self.designerFile.emit(itm.fileName())
-            except:
+            except Exception:
                 pass
         
     def __openFileInEditor(self):
@@ -747,18 +747,18 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         args = []
         self.buf = ""
         
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             if self.project.getProjectType() in ["Qt4", ]:
                 self.uicompiler = 'pyuic4'
                 if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.bat'
+                    uic = Utilities.getWindowsExecutablePath(self.uicompiler)
                 else:
                     uic = self.uicompiler
             elif self.project.getProjectType() in ["PyQt5"]:
                 self.uicompiler = 'pyuic5'
                 if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.bat'
+                    uic = Utilities.getWindowsExecutablePath(self.uicompiler)
                 else:
                     uic = self.uicompiler
             elif self.project.getProjectType() in ["E6Plugin"]:
@@ -767,7 +767,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 else:
                     self.uicompiler = 'pyuic5'
                 if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.bat'
+                    uic = Utilities.getWindowsExecutablePath(self.uicompiler)
                 else:
                     uic = self.uicompiler
             elif self.project.getProjectType() == "PySide":
@@ -775,11 +775,11 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 uic = Utilities.generatePySideToolPath(self.uicompiler)
             else:
                 return None
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             if self.project.getProjectType() == "Qt4":
                 self.uicompiler = 'rbuic4'
                 if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.exe'
+                    uic = Utilities.getWindowsExecutablePath(self.uicompiler)
                 else:
                     uic = self.uicompiler
             else:
@@ -790,7 +790,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         ofn, ext = os.path.splitext(fn)
         fn = os.path.join(self.project.ppath, fn)
         
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             dirname, filename = os.path.split(ofn)
             self.compiledFile = os.path.join(dirname, "Ui_" + filename + ".py")
@@ -800,7 +800,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 args.append("--indent={0}".format(indentWidth))
             if Preferences.getQt("PyuicFromImports"):
                 args.append("--from-imports")
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             self.compiledFile = ofn + '.rb'
             args.append('-x')
         
@@ -965,11 +965,11 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 QApplication.processEvents()
                 
                 ifn = os.path.join(self.project.ppath, fn)
-                if self.project.pdata["PROGLANGUAGE"][0] in \
+                if self.project.getProjectLanguage() in \
                    ["Python", "Python2", "Python3"]:
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(dirname, "Ui_" + filename + ".py")
-                elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+                elif self.project.getProjectLanguage() == "Ruby":
                     ofn = os.path.splitext(ifn)[0] + '.rb'
                 if not os.path.exists(ofn) or \
                    os.stat(ifn).st_mtime > os.stat(ofn).st_mtime:
