@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -86,7 +86,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         
         self.menu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             self.menu.addAction(
                 self.tr('Compile resource'),
@@ -122,7 +122,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.menuActions.append(act)
         self.menu.addSeparator()
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             self.menu.addAction(
                 self.tr('New resource...'), self.__newResource)
@@ -150,7 +150,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
 
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             self.backMenu.addAction(
                 self.tr('Compile all resources'),
@@ -188,7 +188,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.multiMenu.addAction(
                 self.tr('Compile resources'),
@@ -220,7 +220,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
 
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             self.dirMenu.addAction(
                 self.tr('Compile all resources'),
@@ -261,7 +261,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         
         self.dirMultiMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             self.dirMultiMenu.addAction(
                 self.tr('Compile all resources'),
@@ -336,7 +336,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -630,34 +630,48 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         args = []
         self.buf = ""
         
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
-            if self.project.getProjectType() in ["Qt4", "Qt4C", "E4Plugin"]:
+            if self.project.getProjectType() in ["Qt4", "Qt4C"]:
                 self.rccCompiler = 'pyrcc4'
                 if Utilities.isWindowsPlatform():
-                    self.rccCompiler += '.exe'
+                    self.rccCompiler = \
+                        Utilities.getWindowsExecutablePath(self.rccCompiler)
                 if PYQT_VERSION >= 0x040500:
-                    if self.project.pdata["PROGLANGUAGE"][0] in \
+                    if self.project.getProjectLanguage() in \
                             ["Python", "Python2"]:
                         args.append("-py2")
                     else:
                         args.append("-py3")
-            elif self.project.getProjectType() in [
-                    "PyQt5", "PyQt5C", "E6Plugin"]:
+            elif self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
                 self.rccCompiler = 'pyrcc5'
                 if Utilities.isWindowsPlatform():
-                    self.rccCompiler += '.exe'
+                    self.rccCompiler = \
+                        Utilities.getWindowsExecutablePath(self.rccCompiler)
+            elif self.project.getProjectType() in ["E6Plugin"]:
+                if PYQT_VERSION < 0x050000:
+                    self.rccCompiler = 'pyrcc4'
+                    if self.project.getProjectLanguage() in \
+                            ["Python", "Python2"]:
+                        args.append("-py2")
+                    else:
+                        args.append("-py3")
+                else:
+                    self.rccCompiler = 'pyrcc5'
+                if Utilities.isWindowsPlatform():
+                    self.rccCompiler = \
+                        Utilities.getWindowsExecutablePath(self.rccCompiler)
             elif self.project.getProjectType() in ["PySide", "PySideC"]:
                 self.rccCompiler = Utilities.generatePySideToolPath(
                     'pyside-rcc')
-                if self.project.pdata["PROGLANGUAGE"][0] in \
+                if self.project.getProjectLanguage() in \
                         ["Python", "Python2"]:
                     args.append("-py2")
                 else:
                     args.append("-py3")
             else:
                 return None
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             if self.project.getProjectType() == "Qt4":
                 self.rccCompiler = 'rbrcc'
                 if Utilities.isWindowsPlatform():
@@ -673,11 +687,11 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         fn = os.path.join(self.project.ppath, fn)
         
         dirname, filename = os.path.split(ofn)
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             self.compiledFile = os.path.join(
                 dirname, self.RCFilenameFormatPython.format(filename))
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             self.compiledFile = os.path.join(
                 dirname, self.RCFilenameFormatRuby.format(filename))
         
@@ -848,12 +862,12 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                 progress.setValue(i)
                 QApplication.processEvents()
                 ifn = os.path.join(self.project.ppath, fn)
-                if self.project.pdata["PROGLANGUAGE"][0] in \
+                if self.project.getProjectLanguage() in \
                    ["Python", "Python2", "Python3"]:
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(
                         dirname, self.RCFilenameFormatPython.format(filename))
-                elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+                elif self.project.getProjectLanguage() == "Ruby":
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(
                         dirname, self.RCFilenameFormatRuby.format(filename))
