@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,6 +20,7 @@ from E5Gui import E5MessageBox
 
 import Globals
 import UI.PixmapCache
+from UI.Info import Version, Program
 
 import Utilities
 import Preferences
@@ -31,14 +32,25 @@ class TrayStarter(QSystemTrayIcon):
     """
     Class implementing a starter for the system tray.
     """
-    def __init__(self):
+    def __init__(self, usePyQt4, settingsDir, webEngine=False):
         """
         Constructor
+        
+        @param usePyQt4 flag indicating to use PyQt4
+        @type bool
+        @param settingsDir directory to be used for the settings files
+        @type str
+        @keyparam webEngine flag indicating QtWebEngine is used
+        @type bool
         """
         super(TrayStarter, self).__init__(
             UI.PixmapCache.getIcon(
                 Preferences.getTrayStarter("TrayStarterIcon")))
         
+        self.usePyQt4 = usePyQt4
+        self.settingsDir = settingsDir
+        self.__webEngine = webEngine
+        
         self.maxMenuFilePathLen = 75
         
         self.rsettings = QSettings(
@@ -81,6 +93,10 @@ class TrayStarter(QSystemTrayIcon):
         act.setFont(font)
         self.__menu.addSeparator()
         
+        self.__menu.addAction(
+            self.tr("Show Versions"), self.__showVersions)
+        self.__menu.addSeparator()
+        
         self.__menu.addAction(
             self.tr("QRegExp editor"), self.__startQRegExp)
         self.__menu.addAction(
@@ -96,9 +112,6 @@ class TrayStarter(QSystemTrayIcon):
         self.__menu.addAction(
             UI.PixmapCache.getIcon("unittest.png"),
             self.tr("Unittest"), self.__startUnittest)
-        self.__menu.addAction(
-            UI.PixmapCache.getIcon("ericWeb.png"),
-            self.tr("eric6 Web Browser"), self.__startHelpViewer)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
@@ -136,12 +149,20 @@ class TrayStarter(QSystemTrayIcon):
         self.__menu.addAction(
             UI.PixmapCache.getIcon("configure.png"),
             self.tr('Preferences'), self.__startPreferences)
+        self.__menu.addSeparator()
+        
         self.__menu.addAction(
             UI.PixmapCache.getIcon("erict.png"),
             self.tr("eric6 IDE"), self.__startEric)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("editor.png"),
             self.tr("eric6 Mini Editor"), self.__startMiniEditor)
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("hexEditor.png"),
+            self.tr("eric6 Hex Editor"), self.__startHexEditor)
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("ericWeb.png"),
+            self.tr("eric6 Web Browser"), self.__startHelpViewer)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
@@ -234,6 +255,11 @@ class TrayStarter(QSystemTrayIcon):
         
         args = []
         args.append(applPath)
+        if self.usePyQt4:
+            args.append("--pyqt4")
+        args.append("--config={0}".format(Utilities.getConfigDir()))
+        if self.settingsDir:
+            args.append("--settings={0}".format(self.settingsDir))
         for arg in applArgs:
             args.append(arg)
         
@@ -252,120 +278,112 @@ class TrayStarter(QSystemTrayIcon):
         """
         Private slot to start the eric6 Mini Editor.
         """
-        self.__startProc("eric6_editor.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_editor.py")
     
     def __startEric(self):
         """
         Private slot to start the eric6 IDE.
         """
-        self.__startProc("eric6.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6.py")
 
     def __startPreferences(self):
         """
         Private slot to start the eric6 configuration dialog.
         """
-        self.__startProc("eric6_configure.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_configure.py")
 
     def __startPluginInstall(self):
         """
         Private slot to start the eric6 plugin installation dialog.
         """
-        self.__startProc("eric6_plugininstall.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_plugininstall.py")
 
     def __startPluginUninstall(self):
         """
         Private slot to start the eric6 plugin uninstallation dialog.
         """
-        self.__startProc("eric6_pluginuninstall.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_pluginuninstall.py")
 
     def __startPluginRepository(self):
         """
         Private slot to start the eric6 plugin repository dialog.
         """
-        self.__startProc("eric6_pluginrepository.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_pluginrepository.py")
 
     def __startHelpViewer(self):
         """
         Private slot to start the eric6 web browser.
         """
-        self.__startProc("eric6_webbrowser.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        if self.__webEngine:
+            self.__startProc("eric6_browser.py")
+        else:
+            self.__startProc("eric6_webbrowser.py")
 
     def __startUIPreviewer(self):
         """
         Private slot to start the eric6 UI previewer.
         """
-        self.__startProc("eric6_uipreviewer.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_uipreviewer.py")
 
     def __startTRPreviewer(self):
         """
         Private slot to start the eric6 translations previewer.
         """
-        self.__startProc("eric6_trpreviewer.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_trpreviewer.py")
 
     def __startUnittest(self):
         """
         Private slot to start the eric6 unittest dialog.
         """
-        self.__startProc("eric6_unittest.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_unittest.py")
 
     def __startDiff(self):
         """
         Private slot to start the eric6 diff dialog.
         """
-        self.__startProc("eric6_diff.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_diff.py")
 
     def __startCompare(self):
         """
         Private slot to start the eric6 compare dialog.
         """
-        self.__startProc("eric6_compare.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_compare.py")
     
     def __startSqlBrowser(self):
         """
         Private slot to start the eric6 sql browser dialog.
         """
-        self.__startProc("eric6_sqlbrowser.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_sqlbrowser.py")
 
     def __startIconEditor(self):
         """
         Private slot to start the eric6 icon editor dialog.
         """
-        self.__startProc("eric6_iconeditor.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_iconeditor.py")
 
     def __startSnapshot(self):
         """
         Private slot to start the eric6 snapshot dialog.
         """
-        self.__startProc("eric6_snap.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_snap.py")
 
     def __startQRegExp(self):
         """
         Private slot to start the eric6 QRegExp editor dialog.
         """
-        self.__startProc("eric6_qregexp.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_qregexp.py")
 
     def __startPyRe(self):
         """
         Private slot to start the eric6 Python re editor dialog.
         """
-        self.__startProc("eric6_re.py", "--config={0}".format(
-            Utilities.getConfigDir()))
+        self.__startProc("eric6_re.py")
+    
+    def __startHexEditor(self):
+        """
+        Private slot to start the eric6 hex editor dialog.
+        """
+        self.__startProc("eric6_hexeditor.py")
 
     def __showRecentProjectsMenu(self):
         """
@@ -442,7 +460,9 @@ class TrayStarter(QSystemTrayIcon):
         """
         filename = act.data()
         if filename:
-            self.__startProc("eric6.py", filename)
+            self.__startProc(
+                "eric6.py",
+                filename)
     
     def __showPreferences(self):
         """
@@ -477,3 +497,47 @@ class TrayStarter(QSystemTrayIcon):
         from Plugins.AboutPlugin.AboutDialog import AboutDialog
         dlg = AboutDialog()
         dlg.exec_()
+    
+    def __showVersions(self):
+        """
+        Private slot to handle the Versions dialog.
+        """
+        from PyQt5.QtCore import qVersion, PYQT_VERSION_STR
+        from PyQt5.Qsci import QSCINTILLA_VERSION_STR
+        
+        try:
+            import sipconfig
+            sip_version_str = sipconfig.Configuration().sip_version_str
+        except ImportError:
+            sip_version_str = "sip version not available"
+        
+        versionText = self.tr(
+            """<h3>Version Numbers</h3>"""
+            """<table>""")
+        versionText += """<tr><td><b>Python</b></td><td>{0}</td></tr>"""\
+            .format(sys.version.split()[0])
+        versionText += """<tr><td><b>Qt</b></td><td>{0}</td></tr>"""\
+            .format(qVersion())
+        versionText += """<tr><td><b>PyQt</b></td><td>{0}</td></tr>"""\
+            .format(PYQT_VERSION_STR)
+        versionText += """<tr><td><b>sip</b></td><td>{0}</td></tr>"""\
+            .format(sip_version_str)
+        versionText += """<tr><td><b>QScintilla</b></td><td>{0}</td></tr>"""\
+            .format(QSCINTILLA_VERSION_STR)
+        if self.__webEngine:
+            from WebBrowser.Tools import WebBrowserTools
+            chromeVersion = WebBrowserTools.getWebEngineVersions()[0]
+            versionText += \
+                """<tr><td><b>WebEngine</b></td><td>{0}</td></tr>"""\
+                .format(chromeVersion)
+        try:
+            from PyQt5.QtWebKit import qWebKitVersion
+            versionText += """<tr><td><b>WebKit</b></td><td>{0}</td></tr>"""\
+                .format(qWebKitVersion())
+        except ImportError:
+            pass
+        versionText += """<tr><td><b>{0}</b></td><td>{1}</td></tr>"""\
+            .format(Program, Version)
+        versionText += self.tr("""</table>""")
+        
+        E5MessageBox.about(None, Program, versionText)
