@@ -67,9 +67,12 @@ if __name__ == "__main__":
         main(sys.argv)
     except SystemExit:
         raise
-    except:
+    except Exception:
         print(
             "\nAn internal error occured.  Please report all the output of the"
             " program, \nincluding the following traceback, to"
             " eric-bugs@eric-ide.python-projects.org.\n")
         raise
+
+#
+# eflag: noqa = M801
