@@ -30,6 +30,7 @@ import fnmatch
 import distutils.sysconfig
 import codecs
 import subprocess
+import time
 
 # Define the globals.
 progName = None
@@ -306,6 +307,43 @@ def copyDesktopFile(src, dst, marker):
     os.chmod(dst, 0o644)
 
 
+def copyAppStreamFile(src, dst, marker):
+    """
+    Modify an appstream file and write it to its destination.
+    
+    @param src source file name (string)
+    @param dst destination file name (string)
+    @param marker marker to be used (string)
+    """
+    if os.path.exists(os.path.join("eric", "UI", "Info.py")):
+        # Installing from archive
+        from eric.UI.Info import Version
+    elif os.path.exists(os.path.join("UI", "Info.py")):
+        # Installing from source tree
+        from UI.Info import Version
+    else:
+        Version = "Unknown"
+    
+    if sys.version_info[0] == 2:
+        f = codecs.open(src, "r", "utf-8")
+    else:
+        f = open(src, "r", encoding="utf-8")
+    text = f.read()
+    f.close()
+    
+    text = text.replace("@MARKER@", marker)\
+        .replace("@VERSION@", Version.split(None, 1)[0])\
+        .replace("@DATE@", time.strftime("%Y-%m-%d"))
+    
+    if sys.version_info[0] == 2:
+        f = codecs.open(dst, "w", "utf-8")
+    else:
+        f = open(dst, "w", encoding="utf-8")
+    f.write(text)
+    f.close()
+    os.chmod(dst, 0o644)
+
+
 def wrapperName(dname, wfile):
     """
     Create the platform specific name for the wrapper script.
@@ -440,7 +478,7 @@ def createGlobalPluginsDir():
             os.mkdir(pdir, 0o755)
         f = open(fname, "w")
         f.write(
-'''# -*- coding: utf-8 -*-
+            '''# -*- coding: utf-8 -*-
 
 """
 Package containing the global plugins.
@@ -513,7 +551,10 @@ def cleanUp():
                      "/usr/share/appdata/eric6" + marker + ".appdata.xml",
                      "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
                      "/usr/share/applications/eric6_webbrowser" + marker +
-                     ".desktop"]:
+                     ".desktop",
+                     "/usr/share/applications/eric6_browser" + marker +
+                     ".desktop",
+                     ]:
             if os.path.exists(name):
                 os.remove(name)
     
@@ -529,7 +570,7 @@ def cleanUp():
         "eric6_plugininstall", "eric6_pluginuninstall",
         "eric6_pluginrepository", "eric6_sqlbrowser",
         "eric6_webbrowser", "eric6_iconeditor",
-        "eric6_snap",
+        "eric6_snap", "eric6_hexeditor", "eric6_browser",
     ]
     if includePythonVariant:
         marker = PythonMarkers[sys.version_info.major]
@@ -633,12 +674,13 @@ def installEric():
     for name in ["eric6_api", "eric6_doc"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name, False))
     for name in ["eric6_compare", "eric6_configure", "eric6_diff",
-                 "eric6_editor", "eric6_iconeditor", "eric6_plugininstall",
-                 "eric6_pluginrepository", "eric6_pluginuninstall",
-                 "eric6_qregexp", "eric6_qregularexpression", "eric6_re",
-                 "eric6_snap", "eric6_sqlbrowser", "eric6_tray",
-                 "eric6_trpreviewer", "eric6_uipreviewer", "eric6_unittest",
-                 "eric6_webbrowser", "eric6"]:
+                 "eric6_editor", "eric6_hexeditor", "eric6_iconeditor",
+                 "eric6_plugininstall", "eric6_pluginrepository",
+                 "eric6_pluginuninstall", "eric6_qregexp",
+                 "eric6_qregularexpression", "eric6_re", "eric6_snap",
+                 "eric6_sqlbrowser", "eric6_tray", "eric6_trpreviewer",
+                 "eric6_uipreviewer", "eric6_unittest", "eric6_webbrowser",
+                 "eric6_browser", "eric6"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name))
     
     # set install prefix, if not None
@@ -815,11 +857,15 @@ def installEric():
                 os.path.join(sourceDir, "eric6_webbrowser.desktop"),
                 os.path.join(dst, "eric6_webbrowser" + marker + ".desktop"),
                 marker)
+            copyDesktopFile(
+                os.path.join(sourceDir, "eric6_browser.desktop"),
+                os.path.join(dst, "eric6_browser" + marker + ".desktop"),
+                marker)
             dst = os.path.normpath(
                 os.path.join(distDir, "usr/share/metainfo"))
             if not os.path.exists(dst):
                 os.makedirs(dst)
-            copyDesktopFile(
+            copyAppStreamFile(
                 os.path.join(sourceDir, "eric6.appdata.xml"),
                 os.path.join(dst, "eric6" + marker + ".appdata.xml"),
                 marker)
@@ -832,12 +878,12 @@ def installEric():
                 "/usr/share/applications/eric6" + marker + ".desktop",
                 marker)
             if os.path.exists("/usr/share/metainfo"):
-                copyDesktopFile(
+                copyAppStreamFile(
                     os.path.join(sourceDir, "eric6.appdata.xml"),
                     "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
                     marker)
             elif os.path.exists("/usr/share/appdata"):
-                copyDesktopFile(
+                copyAppStreamFile(
                     os.path.join(sourceDir, "eric6.appdata.xml"),
                     "/usr/share/appdata/eric6" + marker + ".appdata.xml",
                     marker)
@@ -849,6 +895,11 @@ def installEric():
                 "/usr/share/applications/eric6_webbrowser" + marker +
                 ".desktop",
                 marker)
+            copyDesktopFile(
+                os.path.join(sourceDir, "eric6_browser.desktop"),
+                "/usr/share/applications/eric6_browser" + marker +
+                ".desktop",
+                marker)
     
     # Create a Mac application bundle
     if sys.platform == "darwin":
@@ -1394,7 +1445,7 @@ def main(argv):
                     print("The configuration dictionary in '{0}' is incorrect."
                           " Aborting".format(arg))
                     exit(6)
-            except:
+            except Exception:
                 cfg = {}
         elif opt == "-m":
             macAppBundleName = arg
@@ -1471,11 +1522,8 @@ def main(argv):
     
     if doCompile:
         print("\nCompiling source files ...")
-        if sys.version_info[0] == 3:
-            skipRe = re.compile(r"DebugClients[\\/]Python[\\/]")
-        else:
-            skipRe = re.compile(r"DebugClients[\\/]Python3[\\/]")
         # Hide compile errors (mainly because of Py2/Py3 differences)
+        skipRe = re.compile(r"DebugClients[\\/]Python[\\/]")
         sys.stdout = io.StringIO()
         if distDir:
             compileall.compile_dir(
@@ -1529,8 +1577,11 @@ if __name__ == "__main__":
         main(sys.argv)
     except SystemExit:
         raise
-    except:
+    except Exception:
         print("""An internal error occured.  Please report all the output"""
               """ of the program,\nincluding the following traceback, to"""
               """ eric-bugs@eric-ide.python-projects.org.\n""")
         raise
+
+#
+# eflag: noqa = M801
